@@ -5,13 +5,14 @@ __license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('DummyPluginWidget',)
 
 from fobi.base import form_element_plugin_widget_registry
+from fobi.contrib.themes.bootstrap3 import UID
 from fobi.contrib.plugins.form_elements.content.dummy.widgets import BaseDummyPluginWidget
 
 class DummyPluginWidget(BaseDummyPluginWidget):
     """
     Dummy plugin widget for Boootstrap 3.
     """
-    theme_uid = 'bootstrap3'
+    theme_uid = UID
     media_js = ['dummy/js/fobi.plugins.form_elements.dummy.js',]
     media_css = ['dummy/css/fobi.plugins.form_elements.dummy.css',]
 
